==> ZenTaoPMS.17.1.php7.0.zip: zentaopms/module/caselib/lang/fr.php <==
<?php
/**
 * The caselib module en file of ZenTaoPMS.
 *
 * @copyright   Copyright 2009-2015 青岛易软天创网络科技有限公司(QingDao Nature Easy Soft Network Technology Co,LTD, www.cnezsoft.com)
 * @license     ZPL(http://zpl.pub/page/zplv12.html) or AGPL(https://www.gnu.org/licenses/agpl-3.0.en.html)
 * @author      Yidong Wang <yidong@cnezsoft.com>
 * @package     caselib
 * @version     $Id: zh-cn.php 4490 2013-02-27 03:27:05Z wyd621@gmail.com $
 * @link        http://www.zentao.net
 */
$lang->caselib->common = 'Case Library';
$lang->caselib->all    = 'All Case Libraries';

$lang->caselib->index            = "Accueil Library";
$lang->caselib->create           = "Créer une Library";
$lang->caselib->edit             = 'Editer Library';
$lang->caselib->browse           = 'Voir CasTests dans Library';
$lang->caselib->view             = 'Détail Library';
$lang->caselib->createCase       = 'Créer CasTest';
$lang->caselib->delete           = "Supprimer Suite";
$lang->caselib->linkVersion      = "Version";
$lang->caselib->deleted          = 'Supprimé';
$lang->caselib->exportTemplet    = 'Exporter Modèle';
$lang->caselib->batchCreateCase  = 'Créer par lot';
$lang->caselib->import           = 'Importer';
$lang->caselib->importAction     = 'Importer CasTest';
$lang->caselib->showImport       = 'Données Importées';

$lang->caselib->id             = 'ID';
$lang->caselib->name           = 'Nom';
$lang->caselib->desc           = 'Description';
$lang->caselib->addedBy        = 'Créé Par';
$lang->caselib->addedDate      = 'Date Création';
$lang->caselib->lastEditedBy   = 'Edité par';
$lang->caselib->lastEditedDate = 'Date Modif';

$lang->caselib->legendDesc = 'Description';

$lang->caselib->libraryDelete = 'Voulez vous supprimer cette library ？';
$lang->caselib->noModule      = "<div>Vous n'avez aucun modules.</div><div>Gérer les modules maintenant.</div>";

==> ZenTaoPMS.17.2.php5.4_5.6.zip: zentaopms/module/caselib/lang/fr.php <==
<?php
/**
 * The caselib module en file of ZenTaoPMS.
 *
 * @copyright   Copyright 2009-2015 青岛易软天创网络科技有限公司(QingDao Nature Easy Soft Network Technology Co,LTD, www.cnezsoft.com)
 * @license     ZPL(http://zpl.pub/page/zplv12.html) or AGPL(https://www.gnu.org/licenses/agpl-3.0.en.html)
 * @author      Yidong Wang <yidong@cnezsoft.com>
 * @package     caselib
 * @version     $Id: zh-cn.php 4490 2013-02-27 03:27:05Z wyd621@gmail.com $
 * @link        http://www.zentao.net
 */
$lang->caselib->common = 'Case Library';
$lang->caselib->all    = 'All Case Libraries';

$lang->caselib->index            = "Accueil Library";
$lang->caselib->create           = "Créer une Library";
$lang->caselib->edit             = 'Editer Library';
$lang->caselib->browse           = 'Voir CasTests dans Library';
$lang->caselib->view             = 'Détail Library';
$lang->caselib->createCase       = 'Créer CasTest';
$lang->caselib->delete           = "Supprimer Suite";
$lang->caselib->linkVersion      = "Version";
$lang->caselib->deleted          = 'Supprimé';
$lang->caselib->exportTemplet    = 'Exporter Modèle';
$lang->caselib->batchCreateCase  = 'Créer par lot';
$lang->caselib->import           = 'Importer';
$lang->caselib->showImport       = 'Données Importées';
$lang->caselib->type             = 'Type';
$lang->caselib->product          = $lang->productCommon;
$lang->caselib->browseAction     = 'Caselib List';
$lang->caselib->deleteAction     = "Delete Caselib";
$lang->caselib->importAction     = 'Importer CasTest';
$lang->caselib->linkVersion      = "Version";

$lang->caselib->id             = 'ID';
$lang->caselib->name           = 'Nom';
$lang->caselib->desc           = 'Description';
$lang->caselib->addedBy        = 'Créé Par';
$lang->caselib->addedDate      = 'Date Création';
$lang->caselib->lastEditedBy   = 'Edité par';
$lang->caselib->lastEditedDate = 'Date Modif';

$lang->caselib->legendDesc = 'Description';

$lang->caselib->libraryDelete = 'Voulez vous supprimer cette library ？';
$lang->caselib->noModule      = "<div>Vous n'avez aucun modules.</div><div>Gérer les modules maintenant.</div>";
